qdldl_python: QDLDL, a free LDL factorization routine (Python wrapper)
======================================================================

Description
-----------

QDLDL, a free LDL factorization routine.

License
-------

Apache 2.0

Upstream Contact
----------------

https://pypi.org/project/qdldl/

